package de.hftstuttgart.dtabackend.utils;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.tmatesoft.svn.core.SVNException;
import org.tmatesoft.svn.core.SVNURL;
import org.tmatesoft.svn.core.auth.BasicAuthenticationManager;
import org.tmatesoft.svn.core.auth.ISVNAuthenticationManager;
import org.tmatesoft.svn.core.auth.SVNAuthentication;
import org.tmatesoft.svn.core.auth.SVNSSHAuthentication;
import org.tmatesoft.svn.core.wc.SVNWCUtil;
import org.tmatesoft.svn.core.wc2.SvnCheckout;
import org.tmatesoft.svn.core.wc2.SvnOperationFactory;
import org.tmatesoft.svn.core.wc2.SvnTarget;

import java.io.File;

public class SVNUtil {

    private static final Logger LOG = LogManager.getLogger(SVNUtil.class);

    public static void checkoutRepository(String svnUrl, String username, String password, String targetPath) {
        try {
            SVNURL url = SVNURL.parseURIDecoded(svnUrl);
            SvnOperationFactory operationFactory = new SvnOperationFactory();
            SvnCheckout checkout = operationFactory.createCheckout();
            checkout.setSingleTarget(SvnTarget.fromFile(new File(targetPath)));
            checkout.setSource(SvnTarget.fromURL(url));
            
            String protocol = url.getProtocol();

            if (protocol.equals("https")) {
            if (username != null && password != null) {
                LOG.debug("Setting SVN credentials");
                operationFactory.setAuthenticationManager(new BasicAuthenticationManager(username, password));
            }
            
        } else if (protocol.equals("svn+ssh")) {
            LOG.debug("Setting credentials for SVN+SSH Authentication");
            
            
            ISVNAuthenticationManager authManager = new BasicAuthenticationManager(new SVNAuthentication[] { new SVNSSHAuthentication(username, password, -1, false)});//SVNWCUtil.createDefaultAuthenticationManager(username, password); 
            
            operationFactory.setAuthenticationManager(authManager);
            
        }

            checkout.run();
            LOG.debug("SVN checkout completed successfully.");
        } catch (SVNException e) {
            LOG.error("Error during SVN checkout", e);
        }
    }
}